@@ -18,10 +18,13 @@ Simulation Classes
   MagneticPoleWholeSpace
   CircularLoopWholeSpace
   ElectrostaticSphere
+  MagnetostaticSphere
 """
 
 from geoana.em.static.sphere import ElectrostaticSphere
 
+from geoana.em.static.sphere import MagnetostaticSphere
+
 from geoana.em.static.wholespace import (
     MagneticDipoleWholeSpace,
     MagneticPoleWholeSpace,
